/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: xvar15.sas
Dateiformat: Dos\Windows
Zeichensatz: Windows-1252
Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_SAS.zip
Version: 10/2019
SAS 9.4 for Windows 

Konstruktion der Hilfsmerkmale fr Scientific Use File Mikrozensus 2015
Datenbeschreibung:
  https://www.gesis.org/missy/metadata/MZ/2015/

Zusammenfhrung der Hilfsmerkmale mit SUF mittels Identifikator satznr

Siehe: 
Schimpl-Neimanns, Bernhard: Varianzschtzung fr Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
berarbeitete Fassung verffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schtzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4

nderungen gegenber frheren Versionen:
* Syntax vereinfacht
* Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale bercksichtigt
  nur Bevlkerung am Hauptwohnsitz
============================================================================= */  

* Lokales Arbeitsverzeichnis eintragen, z. B. 'c:\temp';
libname library 'Arbeitsverzeichnis' ;

* Lokales Datenverzeichnis eintragen;
libname mz 'Datenverzeichnis' ;

options nofmterr;
options compress = binary ;

/* Datendefinition: Mikrozensus 2015 Scientific Use File "mz2015", ggf. ndern 
   ggf. ohne Variablenauswahl

* siehe www.gesis.org/missy/files/documents/MZ/readme/readme_suf2015.pdf
Poststratifikation: Die Hochrechnungsfaktoren der Originaldaten wurden 
nachtrglich mit Bercksichtigung des Haushaltszusammenhangs angepasst 
an Randverteilungen nach:
- EF46 Geschlecht, 
- EF44 Altersgruppen (<15 Jahre, 15-44 Jahre, 45-64 Jahre, >=65 Jahre),
- EF29 Erwerbsstatus (erwerbsttig, nicht erwerbsttig) pro 
- EF1  Bundesland  
Empirisch ergeben sich damit 224 Indikatoren der Hilfsvariablen
(gegenber 190 im MZ 2005 - 2011). 
*/
data temp;
  retain satznr EF1 EF3 EF4 EF5b EF12 EF5a ;
  set mz.mz2015 (keep = EF1 EF3 EF4 EF5a EF5b EF12 EF29 EF30 EF31 EF44 EF46 EF117 EF369 EF371 EF570 EF952);
  * Satznummer der Ausgangsdaten fr spteres Zusammenfhren mit MZ 2015;
  satznr = _n_;
run;

proc sort data = temp; 
     by EF1 EF3 EF4 EF5b EF12 EF5a; 
run;

data temp;
  set temp;
  by EF1 EF3 EF4 EF5b EF12;
  if first.EF1 | first.EF3 | first.EF4 | first.EF5b | first.EF12 then hnr = 1;
run;

data temp1 (keep = EF1 EF3 EF4 EF5b EF12 hhnr);
  set temp ;
  where (hnr=1);
  hhnr = _n_; /* fortlfd. Haushaltsnr. inkl. Gemeinschaftsunterk. */ 
run;

data temp;
  merge temp1 temp;
  by EF1 EF3 EF4 EF5b EF12; 
run;

data temp;
    set temp;
    * Recodierung der Anpassungsmerkmale ;
    ef1r = EF1;
    if (EF44>=0  & EF44<=14) then ef44r=1;
    if (EF44>=15 & EF44<=44) then ef44r=2;
    if (EF44>=45 & EF44<=64) then ef44r=3;
    if (EF44>=65 & EF44<=95) then ef44r=4;
    if (EF44>=-8 & EF44<=-7) then ef44r=-1;
    if (EF46>=1  & EF46<=2)  then ef46r=EF46;
    if (EF46>=-8 & EF46<=-7) then ef46r=-1;
    if (EF29=1)              then ef29r=1;
    if (EF29>=2 & EF29<=4)   then ef29r=2;
    if (EF29>=-8 & EF29<=-7) then ef29r=-1;

    * Hilfsmerkmale fr Varianzschtzung pro Merkmalskombination;
    x1   = (ef1r=1 & ef44r=1 & ef46r=1 & ef29r=2);
    x2   = (ef1r=1 & ef44r=1 & ef46r=2 & ef29r=2);
    x3   = (ef1r=1 & ef44r=2 & ef46r=1 & ef29r=1);
    x4   = (ef1r=1 & ef44r=2 & ef46r=1 & ef29r=2);
    x5   = (ef1r=1 & ef44r=2 & ef46r=2 & ef29r=1);
    x6   = (ef1r=1 & ef44r=2 & ef46r=2 & ef29r=2);
    x7   = (ef1r=1 & ef44r=3 & ef46r=1 & ef29r=1);
    x8   = (ef1r=1 & ef44r=3 & ef46r=1 & ef29r=2);
    x9   = (ef1r=1 & ef44r=3 & ef46r=2 & ef29r=1);
    x10  = (ef1r=1 & ef44r=3 & ef46r=2 & ef29r=2);
    x11  = (ef1r=1 & ef44r=4 & ef46r=1 & ef29r=1);
    x12  = (ef1r=1 & ef44r=4 & ef46r=1 & ef29r=2);
    x13  = (ef1r=1 & ef44r=4 & ef46r=2 & ef29r=1);
    x14  = (ef1r=1 & ef44r=4 & ef46r=2 & ef29r=2);
    x15  = (ef1r=2 & ef44r=1 & ef46r=1 & ef29r=2);
    x16  = (ef1r=2 & ef44r=1 & ef46r=2 & ef29r=2);
    x17  = (ef1r=2 & ef44r=2 & ef46r=1 & ef29r=1);
    x18  = (ef1r=2 & ef44r=2 & ef46r=1 & ef29r=2);
    x19  = (ef1r=2 & ef44r=2 & ef46r=2 & ef29r=1);
    x20  = (ef1r=2 & ef44r=2 & ef46r=2 & ef29r=2);
    x21  = (ef1r=2 & ef44r=3 & ef46r=1 & ef29r=1);
    x22  = (ef1r=2 & ef44r=3 & ef46r=1 & ef29r=2);
    x23  = (ef1r=2 & ef44r=3 & ef46r=2 & ef29r=1);
    x24  = (ef1r=2 & ef44r=3 & ef46r=2 & ef29r=2);
    x25  = (ef1r=2 & ef44r=4 & ef46r=1 & ef29r=1);
    x26  = (ef1r=2 & ef44r=4 & ef46r=1 & ef29r=2);
    x27  = (ef1r=2 & ef44r=4 & ef46r=2 & ef29r=1);
    x28  = (ef1r=2 & ef44r=4 & ef46r=2 & ef29r=2);
    x29  = (ef1r=3 & ef44r=1 & ef46r=1 & ef29r=2);
    x30  = (ef1r=3 & ef44r=1 & ef46r=2 & ef29r=2);
    x31  = (ef1r=3 & ef44r=2 & ef46r=1 & ef29r=1);
    x32  = (ef1r=3 & ef44r=2 & ef46r=1 & ef29r=2);
    x33  = (ef1r=3 & ef44r=2 & ef46r=2 & ef29r=1);
    x34  = (ef1r=3 & ef44r=2 & ef46r=2 & ef29r=2);
    x35  = (ef1r=3 & ef44r=3 & ef46r=1 & ef29r=1);
    x36  = (ef1r=3 & ef44r=3 & ef46r=1 & ef29r=2);
    x37  = (ef1r=3 & ef44r=3 & ef46r=2 & ef29r=1);
    x38  = (ef1r=3 & ef44r=3 & ef46r=2 & ef29r=2);
    x39  = (ef1r=3 & ef44r=4 & ef46r=1 & ef29r=1);
    x40  = (ef1r=3 & ef44r=4 & ef46r=1 & ef29r=2);
    x41  = (ef1r=3 & ef44r=4 & ef46r=2 & ef29r=1);
    x42  = (ef1r=3 & ef44r=4 & ef46r=2 & ef29r=2);
    x43  = (ef1r=4 & ef44r=1 & ef46r=1 & ef29r=2);
    x44  = (ef1r=4 & ef44r=1 & ef46r=2 & ef29r=2);
    x45  = (ef1r=4 & ef44r=2 & ef46r=1 & ef29r=1);
    x46  = (ef1r=4 & ef44r=2 & ef46r=1 & ef29r=2);
    x47  = (ef1r=4 & ef44r=2 & ef46r=2 & ef29r=1);
    x48  = (ef1r=4 & ef44r=2 & ef46r=2 & ef29r=2);
    x49  = (ef1r=4 & ef44r=3 & ef46r=1 & ef29r=1);
    x50  = (ef1r=4 & ef44r=3 & ef46r=1 & ef29r=2);
    x51  = (ef1r=4 & ef44r=3 & ef46r=2 & ef29r=1);
    x52  = (ef1r=4 & ef44r=3 & ef46r=2 & ef29r=2);
    x53  = (ef1r=4 & ef44r=4 & ef46r=1 & ef29r=1);
    x54  = (ef1r=4 & ef44r=4 & ef46r=1 & ef29r=2);
    x55  = (ef1r=4 & ef44r=4 & ef46r=2 & ef29r=1);
    x56  = (ef1r=4 & ef44r=4 & ef46r=2 & ef29r=2);
    x57  = (ef1r=5 & ef44r=1 & ef46r=1 & ef29r=2);
    x58  = (ef1r=5 & ef44r=1 & ef46r=2 & ef29r=2);
    x59  = (ef1r=5 & ef44r=2 & ef46r=1 & ef29r=1);
    x60  = (ef1r=5 & ef44r=2 & ef46r=1 & ef29r=2);
    x61  = (ef1r=5 & ef44r=2 & ef46r=2 & ef29r=1);
    x62  = (ef1r=5 & ef44r=2 & ef46r=2 & ef29r=2);
    x63  = (ef1r=5 & ef44r=3 & ef46r=1 & ef29r=1);
    x64  = (ef1r=5 & ef44r=3 & ef46r=1 & ef29r=2);
    x65  = (ef1r=5 & ef44r=3 & ef46r=2 & ef29r=1);
    x66  = (ef1r=5 & ef44r=3 & ef46r=2 & ef29r=2);
    x67  = (ef1r=5 & ef44r=4 & ef46r=1 & ef29r=1);
    x68  = (ef1r=5 & ef44r=4 & ef46r=1 & ef29r=2);
    x69  = (ef1r=5 & ef44r=4 & ef46r=2 & ef29r=1);
    x70  = (ef1r=5 & ef44r=4 & ef46r=2 & ef29r=2);
    x71  = (ef1r=6 & ef44r=1 & ef46r=1 & ef29r=2);
    x72  = (ef1r=6 & ef44r=1 & ef46r=2 & ef29r=2);
    x73  = (ef1r=6 & ef44r=2 & ef46r=1 & ef29r=1);
    x74  = (ef1r=6 & ef44r=2 & ef46r=1 & ef29r=2);
    x75  = (ef1r=6 & ef44r=2 & ef46r=2 & ef29r=1);
    x76  = (ef1r=6 & ef44r=2 & ef46r=2 & ef29r=2);
    x77  = (ef1r=6 & ef44r=3 & ef46r=1 & ef29r=1);
    x78  = (ef1r=6 & ef44r=3 & ef46r=1 & ef29r=2);
    x79  = (ef1r=6 & ef44r=3 & ef46r=2 & ef29r=1);
    x80  = (ef1r=6 & ef44r=3 & ef46r=2 & ef29r=2);
    x81  = (ef1r=6 & ef44r=4 & ef46r=1 & ef29r=1);
    x82  = (ef1r=6 & ef44r=4 & ef46r=1 & ef29r=2);
    x83  = (ef1r=6 & ef44r=4 & ef46r=2 & ef29r=1);
    x84  = (ef1r=6 & ef44r=4 & ef46r=2 & ef29r=2);
    x85  = (ef1r=7 & ef44r=1 & ef46r=1 & ef29r=2);
    x86  = (ef1r=7 & ef44r=1 & ef46r=2 & ef29r=2);
    x87  = (ef1r=7 & ef44r=2 & ef46r=1 & ef29r=1);
    x88  = (ef1r=7 & ef44r=2 & ef46r=1 & ef29r=2);
    x89  = (ef1r=7 & ef44r=2 & ef46r=2 & ef29r=1);
    x90  = (ef1r=7 & ef44r=2 & ef46r=2 & ef29r=2);
    x91  = (ef1r=7 & ef44r=3 & ef46r=1 & ef29r=1);
    x92  = (ef1r=7 & ef44r=3 & ef46r=1 & ef29r=2);
    x93  = (ef1r=7 & ef44r=3 & ef46r=2 & ef29r=1);
    x94  = (ef1r=7 & ef44r=3 & ef46r=2 & ef29r=2);
    x95  = (ef1r=7 & ef44r=4 & ef46r=1 & ef29r=1);
    x96  = (ef1r=7 & ef44r=4 & ef46r=1 & ef29r=2);
    x97  = (ef1r=7 & ef44r=4 & ef46r=2 & ef29r=1);
    x98  = (ef1r=7 & ef44r=4 & ef46r=2 & ef29r=2);
    x99  = (ef1r=8 & ef44r=1 & ef46r=1 & ef29r=2);
    x100 = (ef1r=8 & ef44r=1 & ef46r=2 & ef29r=2);
    x101 = (ef1r=8 & ef44r=2 & ef46r=1 & ef29r=1);
    x102 = (ef1r=8 & ef44r=2 & ef46r=1 & ef29r=2);
    x103 = (ef1r=8 & ef44r=2 & ef46r=2 & ef29r=1);
    x104 = (ef1r=8 & ef44r=2 & ef46r=2 & ef29r=2);
    x105 = (ef1r=8 & ef44r=3 & ef46r=1 & ef29r=1);
    x106 = (ef1r=8 & ef44r=3 & ef46r=1 & ef29r=2);
    x107 = (ef1r=8 & ef44r=3 & ef46r=2 & ef29r=1);
    x108 = (ef1r=8 & ef44r=3 & ef46r=2 & ef29r=2);
    x109 = (ef1r=8 & ef44r=4 & ef46r=1 & ef29r=1);
    x110 = (ef1r=8 & ef44r=4 & ef46r=1 & ef29r=2);
    x111 = (ef1r=8 & ef44r=4 & ef46r=2 & ef29r=1);
    x112 = (ef1r=8 & ef44r=4 & ef46r=2 & ef29r=2);
    x113 = (ef1r=9 & ef44r=1 & ef46r=1 & ef29r=2);
    x114 = (ef1r=9 & ef44r=1 & ef46r=2 & ef29r=2);
    x115 = (ef1r=9 & ef44r=2 & ef46r=1 & ef29r=1);
    x116 = (ef1r=9 & ef44r=2 & ef46r=1 & ef29r=2);
    x117 = (ef1r=9 & ef44r=2 & ef46r=2 & ef29r=1);
    x118 = (ef1r=9 & ef44r=2 & ef46r=2 & ef29r=2);
    x119 = (ef1r=9 & ef44r=3 & ef46r=1 & ef29r=1);
    x120 = (ef1r=9 & ef44r=3 & ef46r=1 & ef29r=2);
    x121 = (ef1r=9 & ef44r=3 & ef46r=2 & ef29r=1);
    x122 = (ef1r=9 & ef44r=3 & ef46r=2 & ef29r=2);
    x123 = (ef1r=9 & ef44r=4 & ef46r=1 & ef29r=1);
    x124 = (ef1r=9 & ef44r=4 & ef46r=1 & ef29r=2);
    x125 = (ef1r=9 & ef44r=4 & ef46r=2 & ef29r=1);
    x126 = (ef1r=9 & ef44r=4 & ef46r=2 & ef29r=2);
    x127 = (ef1r=10 & ef44r=1 & ef46r=1 & ef29r=2);
    x128 = (ef1r=10 & ef44r=1 & ef46r=2 & ef29r=2);
    x129 = (ef1r=10 & ef44r=2 & ef46r=1 & ef29r=1);
    x130 = (ef1r=10 & ef44r=2 & ef46r=1 & ef29r=2);
    x131 = (ef1r=10 & ef44r=2 & ef46r=2 & ef29r=1);
    x132 = (ef1r=10 & ef44r=2 & ef46r=2 & ef29r=2);
    x133 = (ef1r=10 & ef44r=3 & ef46r=1 & ef29r=1);
    x134 = (ef1r=10 & ef44r=3 & ef46r=1 & ef29r=2);
    x135 = (ef1r=10 & ef44r=3 & ef46r=2 & ef29r=1);
    x136 = (ef1r=10 & ef44r=3 & ef46r=2 & ef29r=2);
    x137 = (ef1r=10 & ef44r=4 & ef46r=1 & ef29r=1);
    x138 = (ef1r=10 & ef44r=4 & ef46r=1 & ef29r=2);
    x139 = (ef1r=10 & ef44r=4 & ef46r=2 & ef29r=1);
    x140 = (ef1r=10 & ef44r=4 & ef46r=2 & ef29r=2);
    x141 = (ef1r=11 & ef44r=1 & ef46r=1 & ef29r=2);
    x142 = (ef1r=11 & ef44r=1 & ef46r=2 & ef29r=2);
    x143 = (ef1r=11 & ef44r=2 & ef46r=1 & ef29r=1);
    x144 = (ef1r=11 & ef44r=2 & ef46r=1 & ef29r=2);
    x145 = (ef1r=11 & ef44r=2 & ef46r=2 & ef29r=1);
    x146 = (ef1r=11 & ef44r=2 & ef46r=2 & ef29r=2);
    x147 = (ef1r=11 & ef44r=3 & ef46r=1 & ef29r=1);
    x148 = (ef1r=11 & ef44r=3 & ef46r=1 & ef29r=2);
    x149 = (ef1r=11 & ef44r=3 & ef46r=2 & ef29r=1);
    x150 = (ef1r=11 & ef44r=3 & ef46r=2 & ef29r=2);
    x151 = (ef1r=11 & ef44r=4 & ef46r=1 & ef29r=1);
    x152 = (ef1r=11 & ef44r=4 & ef46r=1 & ef29r=2);
    x153 = (ef1r=11 & ef44r=4 & ef46r=2 & ef29r=1);
    x154 = (ef1r=11 & ef44r=4 & ef46r=2 & ef29r=2);
    x155 = (ef1r=12 & ef44r=1 & ef46r=1 & ef29r=2);
    x156 = (ef1r=12 & ef44r=1 & ef46r=2 & ef29r=2);
    x157 = (ef1r=12 & ef44r=2 & ef46r=1 & ef29r=1);
    x158 = (ef1r=12 & ef44r=2 & ef46r=1 & ef29r=2);
    x159 = (ef1r=12 & ef44r=2 & ef46r=2 & ef29r=1);
    x160 = (ef1r=12 & ef44r=2 & ef46r=2 & ef29r=2);
    x161 = (ef1r=12 & ef44r=3 & ef46r=1 & ef29r=1);
    x162 = (ef1r=12 & ef44r=3 & ef46r=1 & ef29r=2);
    x163 = (ef1r=12 & ef44r=3 & ef46r=2 & ef29r=1);
    x164 = (ef1r=12 & ef44r=3 & ef46r=2 & ef29r=2);
    x165 = (ef1r=12 & ef44r=4 & ef46r=1 & ef29r=1);
    x166 = (ef1r=12 & ef44r=4 & ef46r=1 & ef29r=2);
    x167 = (ef1r=12 & ef44r=4 & ef46r=2 & ef29r=1);
    x168 = (ef1r=12 & ef44r=4 & ef46r=2 & ef29r=2);
    x169 = (ef1r=13 & ef44r=1 & ef46r=1 & ef29r=2);
    x170 = (ef1r=13 & ef44r=1 & ef46r=2 & ef29r=2);
    x171 = (ef1r=13 & ef44r=2 & ef46r=1 & ef29r=1);
    x172 = (ef1r=13 & ef44r=2 & ef46r=1 & ef29r=2);
    x173 = (ef1r=13 & ef44r=2 & ef46r=2 & ef29r=1);
    x174 = (ef1r=13 & ef44r=2 & ef46r=2 & ef29r=2);
    x175 = (ef1r=13 & ef44r=3 & ef46r=1 & ef29r=1);
    x176 = (ef1r=13 & ef44r=3 & ef46r=1 & ef29r=2);
    x177 = (ef1r=13 & ef44r=3 & ef46r=2 & ef29r=1);
    x178 = (ef1r=13 & ef44r=3 & ef46r=2 & ef29r=2);
    x179 = (ef1r=13 & ef44r=4 & ef46r=1 & ef29r=1);
    x180 = (ef1r=13 & ef44r=4 & ef46r=1 & ef29r=2);
    x181 = (ef1r=13 & ef44r=4 & ef46r=2 & ef29r=1);
    x182 = (ef1r=13 & ef44r=4 & ef46r=2 & ef29r=2);
    x183 = (ef1r=14 & ef44r=1 & ef46r=1 & ef29r=2);
    x184 = (ef1r=14 & ef44r=1 & ef46r=2 & ef29r=2);
    x185 = (ef1r=14 & ef44r=2 & ef46r=1 & ef29r=1);
    x186 = (ef1r=14 & ef44r=2 & ef46r=1 & ef29r=2);
    x187 = (ef1r=14 & ef44r=2 & ef46r=2 & ef29r=1);
    x188 = (ef1r=14 & ef44r=2 & ef46r=2 & ef29r=2);
    x189 = (ef1r=14 & ef44r=3 & ef46r=1 & ef29r=1);
    x190 = (ef1r=14 & ef44r=3 & ef46r=1 & ef29r=2);
    x191 = (ef1r=14 & ef44r=3 & ef46r=2 & ef29r=1);
    x192 = (ef1r=14 & ef44r=3 & ef46r=2 & ef29r=2);
    x193 = (ef1r=14 & ef44r=4 & ef46r=1 & ef29r=1);
    x194 = (ef1r=14 & ef44r=4 & ef46r=1 & ef29r=2);
    x195 = (ef1r=14 & ef44r=4 & ef46r=2 & ef29r=1);
    x196 = (ef1r=14 & ef44r=4 & ef46r=2 & ef29r=2);
    x197 = (ef1r=15 & ef44r=1 & ef46r=1 & ef29r=2);
    x198 = (ef1r=15 & ef44r=1 & ef46r=2 & ef29r=2);
    x199 = (ef1r=15 & ef44r=2 & ef46r=1 & ef29r=1);
    x200 = (ef1r=15 & ef44r=2 & ef46r=1 & ef29r=2);
    x201 = (ef1r=15 & ef44r=2 & ef46r=2 & ef29r=1);
    x202 = (ef1r=15 & ef44r=2 & ef46r=2 & ef29r=2);
    x203 = (ef1r=15 & ef44r=3 & ef46r=1 & ef29r=1);
    x204 = (ef1r=15 & ef44r=3 & ef46r=1 & ef29r=2);
    x205 = (ef1r=15 & ef44r=3 & ef46r=2 & ef29r=1);
    x206 = (ef1r=15 & ef44r=3 & ef46r=2 & ef29r=2);
    x207 = (ef1r=15 & ef44r=4 & ef46r=1 & ef29r=1);
    x208 = (ef1r=15 & ef44r=4 & ef46r=1 & ef29r=2);
    x209 = (ef1r=15 & ef44r=4 & ef46r=2 & ef29r=1);
    x210 = (ef1r=15 & ef44r=4 & ef46r=2 & ef29r=2);
    x211 = (ef1r=16 & ef44r=1 & ef46r=1 & ef29r=2);
    x212 = (ef1r=16 & ef44r=1 & ef46r=2 & ef29r=2);
    x213 = (ef1r=16 & ef44r=2 & ef46r=1 & ef29r=1);
    x214 = (ef1r=16 & ef44r=2 & ef46r=1 & ef29r=2);
    x215 = (ef1r=16 & ef44r=2 & ef46r=2 & ef29r=1);
    x216 = (ef1r=16 & ef44r=2 & ef46r=2 & ef29r=2);
    x217 = (ef1r=16 & ef44r=3 & ef46r=1 & ef29r=1);
    x218 = (ef1r=16 & ef44r=3 & ef46r=1 & ef29r=2);
    x219 = (ef1r=16 & ef44r=3 & ef46r=2 & ef29r=1);
    x220 = (ef1r=16 & ef44r=3 & ef46r=2 & ef29r=2);
    x221 = (ef1r=16 & ef44r=4 & ef46r=1 & ef29r=1);
    x222 = (ef1r=16 & ef44r=4 & ef46r=1 & ef29r=2);
    x223 = (ef1r=16 & ef44r=4 & ef46r=2 & ef29r=1);
    x224 = (ef1r=16 & ef44r=4 & ef46r=2 & ef29r=2);

    * Die Hilfsmerkmale sind nur fr die Bevlkerung am Hauptwohnsitz definiert ;
    array q{224} x1-x224;
      do i = 1 to 224;
        q{i} = q{i}*(ef30>=1 & ef30<=2); 
    end;

    * Bevlkerung am Hauptwohnsitz;
    bevhws = (ef30>=1 & ef30<=2);
run;
quit;

proc sort data = temp; 
     by hhnr; 
run;

* Arithm. Mittelwerte der Hilfsmerkmale auf Haushaltsebene bilden: x*;
* bevhws: Anzahl der Personen am Hauptwohnsitz pro hhnr, incl. Gemeinsch.unterk.;
* x* : Summe der Hilfsmerkmale auf Haushaltsebene, incl. Gemeinsch.unterk.;
proc means data=temp noprint ;
     var bevhws x1-x224 ;
     * class hhnr;
     by hhnr;   
     output out=tmp (drop=_type_ _freq_ ) sum = hhgr x1-x224 ;
run;

data tmp ;
  set tmp; 
  * Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale 
  *   (Bevlkerung am Hauptwohnsitz) ;
  array q11{224} x1-x224;
    do i = 1 to 224;
      if hhgr NE 0 then q11{i} = q11{i} / hhgr;
      if hhgr EQ 0 then q11{i} = 0; 
    end;
run;
quit;

data tmp;
  merge temp (drop = bevhws x1-x224) tmp;
  by hhnr;
run;

data mz.xvar15 (keep=hhnr satznr x1-x224);   
  retain hhnr satznr x1-x224;
  set tmp;
  array q12{224} x1-x224;
    do i = 1 to 224;
      if EF30>=1 & EF30<=2 then q12{i} = q12{i};
      if EF30<1 | EF30>2   then q12{i} = 0; 
    end;
run;

proc sort data = mz.xvar15;
     by satznr; 
run;
